@@ -30,8 +30,6 @@
 #'
 #'   Permitted Values: list of variables
 #'
-#' @param filter Deprecated, please use `restrict_derivation()` instead (see examples).
-#'
 #' @param check_type Check uniqueness?
 #'
 #'   If `"warning"` or `"error"` is specified, the specified message is issued
@@ -53,7 +51,6 @@
 #'
 #' @seealso [derive_var_worst_flag()]
 #'
-#' @author Stefan Bundfuss
 #'
 #' @return The input dataset with the new flag variable added
 #'
@@ -73,8 +70,8 @@
 #'   restrict_derivation(
 #'     derivation = derive_var_extreme_flag,
 #'     args = params(
-#'       by_vars = vars(USUBJID, VSTESTCD, VISIT),
-#'       order = vars(VSTPTNUM),
+#'       by_vars = exprs(USUBJID, VSTESTCD, VISIT),
+#'       order = exprs(VSTPTNUM),
 #'       new_var = LASTFL,
 #'       mode = "last"
 #'     ),
@@ -114,8 +111,8 @@
 #'   input,
 #'   derivation = derive_var_extreme_flag,
 #'   args = params(
-#'     by_vars = vars(USUBJID, PARAMCD),
-#'     order = vars(ADT),
+#'     by_vars = exprs(USUBJID, PARAMCD),
+#'     order = exprs(ADT),
 #'     new_var = ABLFL,
 #'     mode = "last"
 #'   ),
@@ -127,8 +124,8 @@
 #'   input,
 #'   derivation = derive_var_extreme_flag,
 #'   args = params(
-#'     by_vars = vars(USUBJID, PARAMCD),
-#'     order = vars(AVAL, ADT),
+#'     by_vars = exprs(USUBJID, PARAMCD),
+#'     order = exprs(AVAL, ADT),
 #'     new_var = ABLFL,
 #'     mode = "last"
 #'   ),
@@ -140,8 +137,8 @@
 #'   input,
 #'   derivation = derive_var_extreme_flag,
 #'   args = params(
-#'     by_vars = vars(USUBJID, PARAMCD),
-#'     order = vars(desc(AVAL), ADT),
+#'     by_vars = exprs(USUBJID, PARAMCD),
+#'     order = exprs(desc(AVAL), ADT),
 #'     new_var = ABLFL,
 #'     mode = "last"
 #'   ),
@@ -153,8 +150,8 @@
 #'   input,
 #'   derivation = derive_var_extreme_flag,
 #'   args = params(
-#'     by_vars = vars(USUBJID, PARAMCD),
-#'     order = vars(ADT, desc(AVAL)),
+#'     by_vars = exprs(USUBJID, PARAMCD),
+#'     order = exprs(ADT, desc(AVAL)),
 #'     new_var = ABLFL,
 #'     mode = "last"
 #'   ),
@@ -172,8 +169,8 @@
 #'   ) %>%
 #'   derive_var_extreme_flag(
 #'     new_var = AOCCIFL,
-#'     by_vars = vars(USUBJID),
-#'     order = vars(TEMP_AESEVN, AESTDY, AESEQ),
+#'     by_vars = exprs(USUBJID),
+#'     order = exprs(TEMP_AESEVN, AESTDY, AESEQ),
 #'     mode = "first"
 #'   ) %>%
 #'   arrange(USUBJID, AESTDY, AESEQ) %>%
@@ -187,8 +184,8 @@
 #'   ) %>%
 #'   derive_var_extreme_flag(
 #'     new_var = AOCCSIFL,
-#'     by_vars = vars(USUBJID, AEBODSYS),
-#'     order = vars(TEMP_AESEVN, AESTDY, AESEQ),
+#'     by_vars = exprs(USUBJID, AEBODSYS),
+#'     order = exprs(TEMP_AESEVN, AESTDY, AESEQ),
 #'     mode = "first"
 #'   ) %>%
 #'   arrange(USUBJID, AESTDY, AESEQ) %>%
@@ -198,16 +195,11 @@ derive_var_extreme_flag <- function(dataset,
                                     order,
                                     new_var,
                                     mode,
-                                    filter = deprecated(),
                                     check_type = "warning") {
-  if (!missing(filter)) {
-    deprecate_stop("0.7.0", "derive_var_extreme_flag(filter = )", "restrict_derivation(filter = )")
-  }
-
-  new_var <- assert_symbol(enquo(new_var))
+  new_var <- assert_symbol(enexpr(new_var))
   assert_vars(by_vars)
   assert_order_vars(order)
-  assert_data_frame(dataset, required_vars = vars(!!!by_vars, !!!extract_vars(order)))
+  assert_data_frame(dataset, required_vars = exprs(!!!by_vars, !!!extract_vars(order)))
   mode <- assert_character_scalar(mode, values = c("first", "last"), case_sensitive = FALSE)
   check_type <- assert_character_scalar(
     check_type,
@@ -239,6 +231,12 @@ derive_var_extreme_flag <- function(dataset,
 }
 
 #' Adds a Variable Flagging the Maximal / Minimal Value Within a Group of Observations
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function is *deprecated*. Please use `slice_derivation()` / `derive_var_extreme_flag()`
+#' to derive extreme flags and adjust the `order` argument.
+#'
 #' @inheritParams derive_var_extreme_flag
 #' @param dataset Input dataset.
 #' Variables specified by `by_vars`, `order`, `param_var`, and `analysis_var` are expected.
@@ -261,7 +259,7 @@ derive_var_extreme_flag <- function(dataset,
 #'
 #' @details For each group with respect to the variables specified by the `by_vars` parameter,
 #' the maximal / minimal observation of `analysis_var`
-#' is labelled in the `new_var` column as `"Y"`,
+#' is labeled in the `new_var` column as `"Y"`,
 #' if its `param_var` is in `worst_high` / `worst_low`.
 #' Otherwise, it is assigned `NA`.
 #' If there is more than one such maximal / minimal observation,
@@ -272,76 +270,13 @@ derive_var_extreme_flag <- function(dataset,
 #'
 #' @seealso [derive_var_extreme_flag()]
 #'
-#' @author Ondrej Slama
 #'
 #' @return The input dataset with the new flag variable added.
 #'
-#' @family der_gen
-#' @keywords der_gen
+#' @family deprecated
+#' @keywords deprecated
 #'
 #' @export
-#'
-#' @examples
-#' library(tibble)
-#' library(dplyr, warn.conflicts = FALSE)
-#'
-#' input <- tribble(
-#'   ~STUDYID, ~USUBJID,  ~PARAMCD,     ~AVISIT,                  ~ADT, ~AVAL,
-#'   "TEST01",  "PAT01", "PARAM01",  "BASELINE", as.Date("2021-04-27"),  15.0,
-#'   "TEST01",  "PAT01", "PARAM01",  "BASELINE", as.Date("2021-04-25"),  14.0,
-#'   "TEST01",  "PAT01", "PARAM01",  "BASELINE", as.Date("2021-04-23"),  15.0,
-#'   "TEST01",  "PAT01", "PARAM01",    "WEEK 1", as.Date("2021-04-27"),  10.0,
-#'   "TEST01",  "PAT01", "PARAM01",    "WEEK 2", as.Date("2021-04-30"),  12.0,
-#'   "TEST01",  "PAT02", "PARAM01", "SCREENING", as.Date("2021-04-27"),  15.0,
-#'   "TEST01",  "PAT02", "PARAM01",  "BASELINE", as.Date("2021-04-25"),  14.0,
-#'   "TEST01",  "PAT02", "PARAM01",  "BASELINE", as.Date("2021-04-23"),  15.0,
-#'   "TEST01",  "PAT02", "PARAM01",    "WEEK 1", as.Date("2021-04-27"),  10.0,
-#'   "TEST01",  "PAT02", "PARAM01",    "WEEK 2", as.Date("2021-04-30"),  12.0,
-#'   "TEST01",  "PAT01", "PARAM02", "SCREENING", as.Date("2021-04-27"),  15.0,
-#'   "TEST01",  "PAT01", "PARAM02", "SCREENING", as.Date("2021-04-25"),  14.0,
-#'   "TEST01",  "PAT01", "PARAM02", "SCREENING", as.Date("2021-04-23"),  15.0,
-#'   "TEST01",  "PAT01", "PARAM02",  "BASELINE", as.Date("2021-04-27"),  10.0,
-#'   "TEST01",  "PAT01", "PARAM02",    "WEEK 2", as.Date("2021-04-30"),  12.0,
-#'   "TEST01",  "PAT02", "PARAM02", "SCREENING", as.Date("2021-04-27"),  15.0,
-#'   "TEST01",  "PAT02", "PARAM02",  "BASELINE", as.Date("2021-04-25"),  14.0,
-#'   "TEST01",  "PAT02", "PARAM02",    "WEEK 1", as.Date("2021-04-23"),  15.0,
-#'   "TEST01",  "PAT02", "PARAM02",    "WEEK 1", as.Date("2021-04-27"),  10.0,
-#'   "TEST01",  "PAT02", "PARAM02",  "BASELINE", as.Date("2021-04-30"),  12.0,
-#'   "TEST01",  "PAT02", "PARAM03", "SCREENING", as.Date("2021-04-27"),  15.0,
-#'   "TEST01",  "PAT02", "PARAM03",  "BASELINE", as.Date("2021-04-25"),  14.0,
-#'   "TEST01",  "PAT02", "PARAM03",    "WEEK 1", as.Date("2021-04-23"),  15.0,
-#'   "TEST01",  "PAT02", "PARAM03",    "WEEK 1", as.Date("2021-04-27"),  10.0,
-#'   "TEST01",  "PAT02", "PARAM03",  "BASELINE", as.Date("2021-04-30"),  12.0
-#' )
-#'
-#' derive_var_worst_flag(
-#'   input,
-#'   by_vars = vars(USUBJID, PARAMCD, AVISIT),
-#'   order = vars(desc(ADT)),
-#'   new_var = WORSTFL,
-#'   param_var = PARAMCD,
-#'   analysis_var = AVAL,
-#'   worst_high = c("PARAM01", "PARAM03"),
-#'   worst_low = "PARAM02"
-#' )
-#' \dontrun{
-#' # example with ADVS
-#' restrict_derivation(
-#'   advs,
-#'   derivation = derive_var_worst_flag,
-#'   args = params(
-#'     by_vars = vars(USUBJID, PARAMCD, AVISIT),
-#'     order = vars(ADT, ATPTN),
-#'     new_var = WORSTFL,
-#'     param_var = PARAMCD,
-#'     analysis_var = AVAL,
-#'     worst_high = c("SYSBP", "DIABP"),
-#'     worst_low = "RESP"
-#'   ),
-#'   filter = !is.na(AVISIT) & !is.na(AVAL)
-#' )
-#' }
-#'
 derive_var_worst_flag <- function(dataset,
                                   by_vars,
                                   order,
@@ -350,21 +285,25 @@ derive_var_worst_flag <- function(dataset,
                                   analysis_var,
                                   worst_high,
                                   worst_low,
-                                  filter = deprecated(),
                                   check_type = "warning") {
-  if (!missing(filter)) {
-    deprecate_stop("0.7.0", "derive_var_worst_flag(filter = )", "restrict_derivation(filter = )")
-  }
+  ### DEPRECATION
+  deprecate_warn("0.10.0",
+    "derive_var_worst_flag()",
+    details = paste(
+      "Please use `slice_derivation()` / `derive_var_extreme_flag()`",
+      "to derive extreme flags by changing the `order` argument"
+    )
+  )
 
   # perform argument checks
-  new_var <- assert_symbol(enquo(new_var))
-  param_var <- assert_symbol(enquo(param_var))
-  analysis_var <- assert_symbol(enquo(analysis_var))
+  new_var <- assert_symbol(enexpr(new_var))
+  param_var <- assert_symbol(enexpr(param_var))
+  analysis_var <- assert_symbol(enexpr(analysis_var))
   assert_vars(by_vars)
   assert_order_vars(order)
   assert_data_frame(
     dataset,
-    required_vars = quo_c(by_vars, extract_vars(order), param_var, analysis_var)
+    required_vars = expr_c(by_vars, extract_vars(order), param_var, analysis_var)
   )
   assert_character_vector(worst_high)
   assert_character_vector(worst_low)
@@ -379,7 +318,7 @@ derive_var_worst_flag <- function(dataset,
   }
 
   # additional checks for worstflag - parameters not available
-  param_var_str <- as_string(quo_get_expr(param_var))
+  param_var_str <- as_string(param_var)
   if (length(worst_high) > 0 &&
     !all(worst_high %in% dataset[[param_var_str]])) {
     err_msg <- paste0(
@@ -408,7 +347,7 @@ derive_var_worst_flag <- function(dataset,
     derive_var_extreme_flag(
       dataset = dplyr::filter(dataset, !!param_var %in% worst_low),
       by_vars = by_vars,
-      order = quo_c(analysis_var, order),
+      order = expr_c(analysis_var, order),
       new_var = !!new_var,
       mode = "first",
       check_type = check_type
@@ -416,7 +355,7 @@ derive_var_worst_flag <- function(dataset,
     derive_var_extreme_flag(
       dataset = dplyr::filter(dataset, !!param_var %in% worst_high),
       by_vars = by_vars,
-      order = quo_c(quo(desc(!!quo_get_expr(analysis_var))), order),
+      order = expr_c(expr(desc(!!analysis_var)), order),
       new_var = !!new_var,
       mode = "first",
       check_type = check_type
