@@ -18,7 +18,8 @@ list(
     utils_examples = "Utilities used for examples and template scripts: ",
     utils_impute = "Utilities used for date imputation: ",
     utils_print = "Utilities for printing: ",
-    source_specifications = "Source Specifications: ",
+    source_specifications = "Source Objects: ",
+    other_advanced = "Other Advanced Functions: ",
     high_order_function = "Higher Order Functions: ",
     create_aux = "Creating auxiliary datasets: "
   )
